aboutsummaryrefslogtreecommitdiffstats
path: root/cover.go
diff options
context:
space:
mode:
Diffstat (limited to 'cover.go')
-rw-r--r--cover.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/cover.go b/cover.go
index a44ebab..415e22a 100644
--- a/cover.go
+++ b/cover.go
@@ -80,8 +80,8 @@ func (cd *CoverDimensions) UnmarshalJSON(data []byte) error {
return nil
}
-// CoverValidationRecord contains the validation status of a cover file.
-type CoverValidationRecord struct {
+// CoverValidation contains the validation status of a cover file.
+type CoverValidation struct {
Id uint
SrcUrl string `json:"source_url"`
NPages uint `json:"page_count"`